# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Metadata(object):
    """
    NOTE: This class is NOT autogenerated.
    It is essentially a dict that you can attach any properties
    """
    def __init__(self):
        self._dct = {}

    def to_dict(self):
        """
        Already a dict so can just return it
        """
        return self._dct

    @property
    def dct(self):
        return self._dct

    @dct.setter
    def dct(self, dct):
        """
        Will set the dct as long as the value associated with the key
        are all strings
        """
        for key, value in dct.iteritems():
            if not isinstance(value, str):
                raise Exception("All the values of the dict need to be string")

        self._dct = dct

    def to_dict(self):
        """
        Will return the dict object because it is a dict
        """
        return self._dict

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())


    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other): 
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """ 
        Returns true if both objects are not equal
        """
        return not self == other



from __future__ import absolute_import

# import models into model package
from .translation_request_creation_payload import TranslationRequestCreationPayload
from .translation_request import TranslationRequest
from .access_token_creation_payload import AccessTokenCreationPayload
from .topics_resource import TopicsResource
from .translated_text_update_payload import TranslatedTextUpdatePayload
from .tones_resource import TonesResource
from .languages_resource import LanguagesResource
from .language import Language
from .topic import Topic
from .tone import Tone
from .meta import Meta
from .access_token_response_payload import AccessTokenResponsePayload
from .error import Error
from .naakh_error import NaakhError
from .simple_translation_request import SimpleTranslationRequest
from .translated_text import TranslatedText
from .translation_progress import TranslationProgress
from .metadata import Metadata



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class AccessTokenCreationPayload(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AccessTokenCreationPayload - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'oauth_client_id': 'str',
            'oauth_client_secret': 'str',
            'password': 'str',
            'phone_number': 'str'
        }

        self.attribute_map = {
            'oauth_client_id': 'oauth_client_id',
            'oauth_client_secret': 'oauth_client_secret',
            'password': 'password',
            'phone_number': 'phone_number'
        }

        self._oauth_client_id = None
        self._oauth_client_secret = None
        self._password = None
        self._phone_number = None

    @property
    def oauth_client_id(self):
        """
        Gets the oauth_client_id of this AccessTokenCreationPayload.


        :return: The oauth_client_id of this AccessTokenCreationPayload.
        :rtype: str
        """
        return self._oauth_client_id

    @oauth_client_id.setter
    def oauth_client_id(self, oauth_client_id):
        """
        Sets the oauth_client_id of this AccessTokenCreationPayload.


        :param oauth_client_id: The oauth_client_id of this AccessTokenCreationPayload.
        :type: str
        """
        self._oauth_client_id = oauth_client_id

    @property
    def oauth_client_secret(self):
        """
        Gets the oauth_client_secret of this AccessTokenCreationPayload.


        :return: The oauth_client_secret of this AccessTokenCreationPayload.
        :rtype: str
        """
        return self._oauth_client_secret

    @oauth_client_secret.setter
    def oauth_client_secret(self, oauth_client_secret):
        """
        Sets the oauth_client_secret of this AccessTokenCreationPayload.


        :param oauth_client_secret: The oauth_client_secret of this AccessTokenCreationPayload.
        :type: str
        """
        self._oauth_client_secret = oauth_client_secret

    @property
    def password(self):
        """
        Gets the password of this AccessTokenCreationPayload.


        :return: The password of this AccessTokenCreationPayload.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this AccessTokenCreationPayload.


        :param password: The password of this AccessTokenCreationPayload.
        :type: str
        """
        self._password = password

    @property
    def phone_number(self):
        """
        Gets the phone_number of this AccessTokenCreationPayload.


        :return: The phone_number of this AccessTokenCreationPayload.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this AccessTokenCreationPayload.


        :param phone_number: The phone_number of this AccessTokenCreationPayload.
        :type: str
        """
        self._phone_number = phone_number

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other): 
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """ 
        Returns true if both objects are not equal
        """
        return not self == other




from __future__ import absolute_import

# import models into sdk package
from .models.translation_request_creation_payload import TranslationRequestCreationPayload
from .models.translation_request import TranslationRequest
from .models.access_token_creation_payload import AccessTokenCreationPayload
from .models.topics_resource import TopicsResource
from .models.translated_text_update_payload import TranslatedTextUpdatePayload
from .models.tones_resource import TonesResource
from .models.languages_resource import LanguagesResource
from .models.language import Language
from .models.topic import Topic
from .models.tone import Tone
from .models.meta import Meta
from .models.access_token_response_payload import AccessTokenResponsePayload
from .models.error import Error
from .models.naakh_error import NaakhError
from .models.simple_translation_request import SimpleTranslationRequest
from .models.translated_text import TranslatedText
from .models.translation_progress import TranslationProgress
from .models.metadata import Metadata

# import apis into sdk package
from .apis.translation_api import TranslationApi
from .apis.translatedtext_api import TranslatedtextApi
from .apis.tones_api import TonesApi
from .apis.oauth_api import OauthApi
from .apis.topics_api import TopicsApi
from .apis.translate_api import TranslateApi
from .apis.languages_api import LanguagesApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class TranslatedText(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TranslatedText - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'final_verification_complete': 'bool',
            'language': 'str',
            'metadata': 'str',
            'status': 'str',
            'translation_request': 'SimpleTranslationRequest',
            'translation_text': 'str',
            'uuid': 'str',
            'verified_context': 'bool',
            'verified_grammar': 'bool',
            'verified_spelling': 'bool'
        }

        self.attribute_map = {
            'final_verification_complete': 'final_verification_complete',
            'language': 'language',
            'metadata': 'metadata',
            'status': 'status',
            'translation_request': 'translation_request',
            'translation_text': 'translation_text',
            'uuid': 'uuid',
            'verified_context': 'verified_context',
            'verified_grammar': 'verified_grammar',
            'verified_spelling': 'verified_spelling'
        }

        self._final_verification_complete = None
        self._language = None
        self._metadata = None
        self._status = None
        self._translation_request = None
        self._translation_text = None
        self._uuid = None
        self._verified_context = None
        self._verified_grammar = None
        self._verified_spelling = None

    @property
    def final_verification_complete(self):
        """
        Gets the final_verification_complete of this TranslatedText.


        :return: The final_verification_complete of this TranslatedText.
        :rtype: bool
        """
        return self._final_verification_complete

    @final_verification_complete.setter
    def final_verification_complete(self, final_verification_complete):
        """
        Sets the final_verification_complete of this TranslatedText.


        :param final_verification_complete: The final_verification_complete of this TranslatedText.
        :type: bool
        """
        self._final_verification_complete = final_verification_complete

    @property
    def language(self):
        """
        Gets the language of this TranslatedText.


        :return: The language of this TranslatedText.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this TranslatedText.


        :param language: The language of this TranslatedText.
        :type: str
        """
        self._language = language

    @property
    def metadata(self):
        """
        Gets the metadata of this TranslatedText.


        :return: The metadata of this TranslatedText.
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this TranslatedText.


        :param metadata: The metadata of this TranslatedText.
        :type: str
        """
        self._metadata = metadata

    @property
    def status(self):
        """
        Gets the status of this TranslatedText.


        :return: The status of this TranslatedText.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this TranslatedText.


        :param status: The status of this TranslatedText.
        :type: str
        """
        self._status = status

    @property
    def translation_request(self):
        """
        Gets the translation_request of this TranslatedText.


        :return: The translation_request of this TranslatedText.
        :rtype: SimpleTranslationRequest
        """
        return self._translation_request

    @translation_request.setter
    def translation_request(self, translation_request):
        """
        Sets the translation_request of this TranslatedText.


        :param translation_request: The translation_request of this TranslatedText.
        :type: SimpleTranslationRequest
        """
        self._translation_request = translation_request

    @property
    def translation_text(self):
        """
        Gets the translation_text of this TranslatedText.


        :return: The translation_text of this TranslatedText.
        :rtype: str
        """
        return self._translation_text

    @translation_text.setter
    def translation_text(self, translation_text):
        """
        Sets the translation_text of this TranslatedText.


        :param translation_text: The translation_text of this TranslatedText.
        :type: str
        """
        self._translation_text = translation_text

    @property
    def uuid(self):
        """
        Gets the uuid of this TranslatedText.


        :return: The uuid of this TranslatedText.
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """
        Sets the uuid of this TranslatedText.


        :param uuid: The uuid of this TranslatedText.
        :type: str
        """
        self._uuid = uuid

    @property
    def verified_context(self):
        """
        Gets the verified_context of this TranslatedText.


        :return: The verified_context of this TranslatedText.
        :rtype: bool
        """
        return self._verified_context

    @verified_context.setter
    def verified_context(self, verified_context):
        """
        Sets the verified_context of this TranslatedText.


        :param verified_context: The verified_context of this TranslatedText.
        :type: bool
        """
        self._verified_context = verified_context

    @property
    def verified_grammar(self):
        """
        Gets the verified_grammar of this TranslatedText.


        :return: The verified_grammar of this TranslatedText.
        :rtype: bool
        """
        return self._verified_grammar

    @verified_grammar.setter
    def verified_grammar(self, verified_grammar):
        """
        Sets the verified_grammar of this TranslatedText.


        :param verified_grammar: The verified_grammar of this TranslatedText.
        :type: bool
        """
        self._verified_grammar = verified_grammar

    @property
    def verified_spelling(self):
        """
        Gets the verified_spelling of this TranslatedText.


        :return: The verified_spelling of this TranslatedText.
        :rtype: bool
        """
        return self._verified_spelling

    @verified_spelling.setter
    def verified_spelling(self, verified_spelling):
        """
        Sets the verified_spelling of this TranslatedText.


        :param verified_spelling: The verified_spelling of this TranslatedText.
        :type: bool
        """
        self._verified_spelling = verified_spelling

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other): 
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """ 
        Returns true if both objects are not equal
        """
        return not self == other




from __future__ import absolute_import

# import apis into api package
from .translation_api import TranslationApi
from .translatedtext_api import TranslatedtextApi
from .tones_api import TonesApi
from .oauth_api import OauthApi
from .topics_api import TopicsApi
from .translate_api import TranslateApi
from .languages_api import LanguagesApi



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class TranslationRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TranslationRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'client': 'str',
            'created_at': 'datetime',
            'instructions': 'str',
            'metadata': 'Metadata',
            'source_language': 'str',
            'target_audience': 'str',
            'target_languages': 'list[str]',
            'text': 'str',
            'tone': 'str',
            'topics': 'list[str]',
            'translation_progress': 'list[TranslationProgress]',
            'uuid': 'str'
        }

        self.attribute_map = {
            'client': 'client',
            'created_at': 'created_at',
            'instructions': 'instructions',
            'metadata': 'metadata',
            'source_language': 'source_language',
            'target_audience': 'target_audience',
            'target_languages': 'target_languages',
            'text': 'text',
            'tone': 'tone',
            'topics': 'topics',
            'translation_progress': 'translation_progress',
            'uuid': 'uuid'
        }

        self._client = None
        self._created_at = None
        self._instructions = None
        self._metadata = None
        self._source_language = None
        self._target_audience = None
        self._target_languages = None
        self._text = None
        self._tone = None
        self._topics = None
        self._translation_progress = None
        self._uuid = None

    @property
    def client(self):
        """
        Gets the client of this TranslationRequest.


        :return: The client of this TranslationRequest.
        :rtype: str
        """
        return self._client

    @client.setter
    def client(self, client):
        """
        Sets the client of this TranslationRequest.


        :param client: The client of this TranslationRequest.
        :type: str
        """
        self._client = client

    @property
    def created_at(self):
        """
        Gets the created_at of this TranslationRequest.


        :return: The created_at of this TranslationRequest.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this TranslationRequest.


        :param created_at: The created_at of this TranslationRequest.
        :type: datetime
        """
        self._created_at = created_at

    @property
    def instructions(self):
        """
        Gets the instructions of this TranslationRequest.


        :return: The instructions of this TranslationRequest.
        :rtype: str
        """
        return self._instructions

    @instructions.setter
    def instructions(self, instructions):
        """
        Sets the instructions of this TranslationRequest.


        :param instructions: The instructions of this TranslationRequest.
        :type: str
        """
        self._instructions = instructions

    @property
    def metadata(self):
        """
        Gets the metadata of this TranslationRequest.


        :return: The metadata of this TranslationRequest.
        :rtype: Metadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this TranslationRequest.


        :param metadata: The metadata of this TranslationRequest.
        :type: Metadata
        """
        self._metadata = metadata

    @property
    def source_language(self):
        """
        Gets the source_language of this TranslationRequest.


        :return: The source_language of this TranslationRequest.
        :rtype: str
        """
        return self._source_language

    @source_language.setter
    def source_language(self, source_language):
        """
        Sets the source_language of this TranslationRequest.


        :param source_language: The source_language of this TranslationRequest.
        :type: str
        """
        self._source_language = source_language

    @property
    def target_audience(self):
        """
        Gets the target_audience of this TranslationRequest.


        :return: The target_audience of this TranslationRequest.
        :rtype: str
        """
        return self._target_audience

    @target_audience.setter
    def target_audience(self, target_audience):
        """
        Sets the target_audience of this TranslationRequest.


        :param target_audience: The target_audience of this TranslationRequest.
        :type: str
        """
        self._target_audience = target_audience

    @property
    def target_languages(self):
        """
        Gets the target_languages of this TranslationRequest.


        :return: The target_languages of this TranslationRequest.
        :rtype: list[str]
        """
        return self._target_languages

    @target_languages.setter
    def target_languages(self, target_languages):
        """
        Sets the target_languages of this TranslationRequest.


        :param target_languages: The target_languages of this TranslationRequest.
        :type: list[str]
        """
        self._target_languages = target_languages

    @property
    def text(self):
        """
        Gets the text of this TranslationRequest.


        :return: The text of this TranslationRequest.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this TranslationRequest.


        :param text: The text of this TranslationRequest.
        :type: str
        """
        self._text = text

    @property
    def tone(self):
        """
        Gets the tone of this TranslationRequest.


        :return: The tone of this TranslationRequest.
        :rtype: str
        """
        return self._tone

    @tone.setter
    def tone(self, tone):
        """
        Sets the tone of this TranslationRequest.


        :param tone: The tone of this TranslationRequest.
        :type: str
        """
        self._tone = tone

    @property
    def topics(self):
        """
        Gets the topics of this TranslationRequest.


        :return: The topics of this TranslationRequest.
        :rtype: list[str]
        """
        return self._topics

    @topics.setter
    def topics(self, topics):
        """
        Sets the topics of this TranslationRequest.


        :param topics: The topics of this TranslationRequest.
        :type: list[str]
        """
        self._topics = topics

    @property
    def translation_progress(self):
        """
        Gets the translation_progress of this TranslationRequest.


        :return: The translation_progress of this TranslationRequest.
        :rtype: list[TranslationProgress]
        """
        return self._translation_progress

    @translation_progress.setter
    def translation_progress(self, translation_progress):
        """
        Sets the translation_progress of this TranslationRequest.


        :param translation_progress: The translation_progress of this TranslationRequest.
        :type: list[TranslationProgress]
        """
        self._translation_progress = translation_progress

    @property
    def uuid(self):
        """
        Gets the uuid of this TranslationRequest.


        :return: The uuid of this TranslationRequest.
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """
        Sets the uuid of this TranslationRequest.


        :param uuid: The uuid of this TranslationRequest.
        :type: str
        """
        self._uuid = uuid

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other): 
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """ 
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class TranslationRequestCreationPayload(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TranslationRequestCreationPayload - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'cancel': 'bool',
            'instructions': 'str',
            'metadata': 'Metadata',
            'source_language': 'str',
            'target_audience': 'str',
            'target_languages': 'list[str]',
            'text': 'str',
            'tone': 'str',
            'topics': 'list[str]',
            'web_url': 'str'
        }

        self.attribute_map = {
            'cancel': 'cancel',
            'instructions': 'instructions',
            'metadata': 'metadata',
            'source_language': 'source_language',
            'target_audience': 'target_audience',
            'target_languages': 'target_languages',
            'text': 'text',
            'tone': 'tone',
            'topics': 'topics',
            'web_url': 'web_url'
        }

        self._cancel = None
        self._instructions = None
        self._metadata = None
        self._source_language = None
        self._target_audience = None
        self._target_languages = None
        self._text = None
        self._tone = None
        self._topics = None
        self._web_url = None

    @property
    def cancel(self):
        """
        Gets the cancel of this TranslationRequestCreationPayload.


        :return: The cancel of this TranslationRequestCreationPayload.
        :rtype: bool
        """
        return self._cancel

    @cancel.setter
    def cancel(self, cancel):
        """
        Sets the cancel of this TranslationRequestCreationPayload.


        :param cancel: The cancel of this TranslationRequestCreationPayload.
        :type: bool
        """
        self._cancel = cancel

    @property
    def instructions(self):
        """
        Gets the instructions of this TranslationRequestCreationPayload.


        :return: The instructions of this TranslationRequestCreationPayload.
        :rtype: str
        """
        return self._instructions

    @instructions.setter
    def instructions(self, instructions):
        """
        Sets the instructions of this TranslationRequestCreationPayload.


        :param instructions: The instructions of this TranslationRequestCreationPayload.
        :type: str
        """
        self._instructions = instructions

    @property
    def metadata(self):
        """
        Gets the metadata of this TranslationRequestCreationPayload.


        :return: The metadata of this TranslationRequestCreationPayload.
        :rtype: Metadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this TranslationRequestCreationPayload.


        :param metadata: The metadata of this TranslationRequestCreationPayload.
        :type: Metadata
        """
        self._metadata = metadata

    @property
    def source_language(self):
        """
        Gets the source_language of this TranslationRequestCreationPayload.


        :return: The source_language of this TranslationRequestCreationPayload.
        :rtype: str
        """
        return self._source_language

    @source_language.setter
    def source_language(self, source_language):
        """
        Sets the source_language of this TranslationRequestCreationPayload.


        :param source_language: The source_language of this TranslationRequestCreationPayload.
        :type: str
        """
        self._source_language = source_language

    @property
    def target_audience(self):
        """
        Gets the target_audience of this TranslationRequestCreationPayload.


        :return: The target_audience of this TranslationRequestCreationPayload.
        :rtype: str
        """
        return self._target_audience

    @target_audience.setter
    def target_audience(self, target_audience):
        """
        Sets the target_audience of this TranslationRequestCreationPayload.


        :param target_audience: The target_audience of this TranslationRequestCreationPayload.
        :type: str
        """
        self._target_audience = target_audience

    @property
    def target_languages(self):
        """
        Gets the target_languages of this TranslationRequestCreationPayload.


        :return: The target_languages of this TranslationRequestCreationPayload.
        :rtype: list[str]
        """
        return self._target_languages

    @target_languages.setter
    def target_languages(self, target_languages):
        """
        Sets the target_languages of this TranslationRequestCreationPayload.


        :param target_languages: The target_languages of this TranslationRequestCreationPayload.
        :type: list[str]
        """
        self._target_languages = target_languages

    @property
    def text(self):
        """
        Gets the text of this TranslationRequestCreationPayload.


        :return: The text of this TranslationRequestCreationPayload.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this TranslationRequestCreationPayload.


        :param text: The text of this TranslationRequestCreationPayload.
        :type: str
        """
        self._text = text

    @property
    def tone(self):
        """
        Gets the tone of this TranslationRequestCreationPayload.


        :return: The tone of this TranslationRequestCreationPayload.
        :rtype: str
        """
        return self._tone

    @tone.setter
    def tone(self, tone):
        """
        Sets the tone of this TranslationRequestCreationPayload.


        :param tone: The tone of this TranslationRequestCreationPayload.
        :type: str
        """
        self._tone = tone

    @property
    def topics(self):
        """
        Gets the topics of this TranslationRequestCreationPayload.


        :return: The topics of this TranslationRequestCreationPayload.
        :rtype: list[str]
        """
        return self._topics

    @topics.setter
    def topics(self, topics):
        """
        Sets the topics of this TranslationRequestCreationPayload.


        :param topics: The topics of this TranslationRequestCreationPayload.
        :type: list[str]
        """
        self._topics = topics

    @property
    def web_url(self):
        """
        Gets the web_url of this TranslationRequestCreationPayload.


        :return: The web_url of this TranslationRequestCreationPayload.
        :rtype: str
        """
        return self._web_url

    @web_url.setter
    def web_url(self, web_url):
        """
        Sets the web_url of this TranslationRequestCreationPayload.


        :param web_url: The web_url of this TranslationRequestCreationPayload.
        :type: str
        """
        self._web_url = web_url

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other): 
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """ 
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class TranslationProgress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TranslationProgress - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'language': 'str',
            'status': 'str',
            'translated_text': 'str',
            'uuid': 'str'
        }

        self.attribute_map = {
            'language': 'language',
            'status': 'status',
            'translated_text': 'translated_text',
            'uuid': 'uuid'
        }

        self._language = None
        self._status = None
        self._translated_text = None
        self._uuid = None

    @property
    def language(self):
        """
        Gets the language of this TranslationProgress.


        :return: The language of this TranslationProgress.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this TranslationProgress.


        :param language: The language of this TranslationProgress.
        :type: str
        """
        self._language = language

    @property
    def status(self):
        """
        Gets the status of this TranslationProgress.


        :return: The status of this TranslationProgress.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this TranslationProgress.


        :param status: The status of this TranslationProgress.
        :type: str
        """
        self._status = status

    @property
    def translated_text(self):
        """
        Gets the translated_text of this TranslationProgress.


        :return: The translated_text of this TranslationProgress.
        :rtype: str
        """
        return self._translated_text

    @translated_text.setter
    def translated_text(self, translated_text):
        """
        Sets the translated_text of this TranslationProgress.


        :param translated_text: The translated_text of this TranslationProgress.
        :type: str
        """
        self._translated_text = translated_text

    @property
    def uuid(self):
        """
        Gets the uuid of this TranslationProgress.


        :return: The uuid of this TranslationProgress.
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """
        Sets the uuid of this TranslationProgress.


        :param uuid: The uuid of this TranslationProgress.
        :type: str
        """
        self._uuid = uuid

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other): 
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """ 
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class AccessTokenResponsePayload(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AccessTokenResponsePayload - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'access_token': 'str',
            'expires_in': 'float',
            'scope': 'str'
        }

        self.attribute_map = {
            'access_token': 'access_token',
            'expires_in': 'expires_in',
            'scope': 'scope'
        }

        self._access_token = None
        self._expires_in = None
        self._scope = None

    @property
    def access_token(self):
        """
        Gets the access_token of this AccessTokenResponsePayload.


        :return: The access_token of this AccessTokenResponsePayload.
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """
        Sets the access_token of this AccessTokenResponsePayload.


        :param access_token: The access_token of this AccessTokenResponsePayload.
        :type: str
        """
        self._access_token = access_token

    @property
    def expires_in(self):
        """
        Gets the expires_in of this AccessTokenResponsePayload.


        :return: The expires_in of this AccessTokenResponsePayload.
        :rtype: float
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """
        Sets the expires_in of this AccessTokenResponsePayload.


        :param expires_in: The expires_in of this AccessTokenResponsePayload.
        :type: float
        """
        self._expires_in = expires_in

    @property
    def scope(self):
        """
        Gets the scope of this AccessTokenResponsePayload.


        :return: The scope of this AccessTokenResponsePayload.
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this AccessTokenResponsePayload.


        :param scope: The scope of this AccessTokenResponsePayload.
        :type: str
        """
        self._scope = scope

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other): 
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """ 
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

import sys
from setuptools import setup, find_packages

NAME = "naakh"
VERSION = "0.0.4"



# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.10", "six >= 1.9", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Naakh Translations",
    author="Rohith Salim",
    author_email="rohitsalim@gmail.com",
    keywords=["Swagger", "Naakh Translations"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    url="https://github.com/Naakh/naakh-py",
    download_url="https://github.com/Naakh/naakh-py/tarball/0.0.4",
    long_description="""\
    This is the python library that developers can use to query the Naakh API
    """
)





# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class SimpleTranslationRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SimpleTranslationRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'client': 'str',
            'created_at': 'datetime',
            'source_language': 'str',
            'target_languages': 'list[str]',
            'text': 'str',
            'uuid': 'str'
        }

        self.attribute_map = {
            'client': 'client',
            'created_at': 'created_at',
            'source_language': 'source_language',
            'target_languages': 'target_languages',
            'text': 'text',
            'uuid': 'uuid'
        }

        self._client = None
        self._created_at = None
        self._source_language = None
        self._target_languages = None
        self._text = None
        self._uuid = None

    @property
    def client(self):
        """
        Gets the client of this SimpleTranslationRequest.


        :return: The client of this SimpleTranslationRequest.
        :rtype: str
        """
        return self._client

    @client.setter
    def client(self, client):
        """
        Sets the client of this SimpleTranslationRequest.


        :param client: The client of this SimpleTranslationRequest.
        :type: str
        """
        self._client = client

    @property
    def created_at(self):
        """
        Gets the created_at of this SimpleTranslationRequest.


        :return: The created_at of this SimpleTranslationRequest.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this SimpleTranslationRequest.


        :param created_at: The created_at of this SimpleTranslationRequest.
        :type: datetime
        """
        self._created_at = created_at

    @property
    def source_language(self):
        """
        Gets the source_language of this SimpleTranslationRequest.


        :return: The source_language of this SimpleTranslationRequest.
        :rtype: str
        """
        return self._source_language

    @source_language.setter
    def source_language(self, source_language):
        """
        Sets the source_language of this SimpleTranslationRequest.


        :param source_language: The source_language of this SimpleTranslationRequest.
        :type: str
        """
        self._source_language = source_language

    @property
    def target_languages(self):
        """
        Gets the target_languages of this SimpleTranslationRequest.


        :return: The target_languages of this SimpleTranslationRequest.
        :rtype: list[str]
        """
        return self._target_languages

    @target_languages.setter
    def target_languages(self, target_languages):
        """
        Sets the target_languages of this SimpleTranslationRequest.


        :param target_languages: The target_languages of this SimpleTranslationRequest.
        :type: list[str]
        """
        self._target_languages = target_languages

    @property
    def text(self):
        """
        Gets the text of this SimpleTranslationRequest.


        :return: The text of this SimpleTranslationRequest.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this SimpleTranslationRequest.


        :param text: The text of this SimpleTranslationRequest.
        :type: str
        """
        self._text = text

    @property
    def uuid(self):
        """
        Gets the uuid of this SimpleTranslationRequest.


        :return: The uuid of this SimpleTranslationRequest.
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """
        Sets the uuid of this SimpleTranslationRequest.


        :param uuid: The uuid of this SimpleTranslationRequest.
        :type: str
        """
        self._uuid = uuid

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other): 
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """ 
        Returns true if both objects are not equal
        """
        return not self == other

